diff --git a/src/class/init.php b/src/class/init.php
deleted file mode 100644
index 9033738..0000000
--- a/src/class/init.php
+++ /dev/null
@@ -1,471 +0,0 @@
-initialize_dashboard();
- // Initialize the Plugin Task.
- $this->initialize_task();
-
- // Register all Public Stylesheets and Scripts.
- add_action( 'init', array( $this, 'register_public' ) );
- // Enqueue all Public Stylesheets and Scripts.
- add_action( 'wp_enqueue_scripts', array( $this, 'register_public' ) );
- // Register all Widgets of the Plugin..
- add_action( 'widgets_init', array( $this, 'initialize_widgets' ) );
- }
-
- /**
- * Initializes all Widgets of the Plugin.
- *
- * @since 1.5.0
- *
- * - Update: Fix for deprecated PHP function create_function(), thanks to @psykonevro @daliasued bug reports, thanks to @felipelavinz code contribution
- *
- * @since 1.6.5
- *
- * @contributor @felipelavinz
- * @link https://github.com/media-competence-institute/footnotes/commit/87173d2980c7ff90e12ffee94ca7153e11163793
- *
- * @reporter @psykonevro
- * @link https://wordpress.org/support/topic/bug-function-create_function-is-deprecated/
- * @link https://wordpress.org/support/topic/deprecated-function-create_function-14/
- *
- * @reporter @daliasued
- * @link https://wordpress.org/support/topic/deprecated-function-create_function-14/#post-13312853
- *
- * create_function() was deprecated in PHP 7.2.0 and removed in PHP 8.0.0.
- * @link https://www.php.net/manual/en/function.create-function.php
- *
- * The fix is to move add_action() above into run(),
- * and use the bare register_widget() here.
- * @see self::run()
- *
- * Also, the visibility of initialize_widgets() is not private any longer.
- */
- public function initialize_widgets() {
- register_widget( 'Footnotes_Widget_Reference_Container' );
- }
-
- /**
- * Initializes the Dashboard of the Plugin and loads them.
- *
- * @since 1.5.0
- */
- private function initialize_dashboard() {
- new Footnotes_Layout_Init();
- }
-
- /**
- * Initializes the Plugin Task and registers the Task hooks.
- *
- * @since 1.5.0
- */
- private function initialize_task() {
- $this->a_obj_task = new Footnotes_Task();
- $this->a_obj_task->register_hooks();
- }
-
- /**
- * Registers and enqueues scripts and stylesheets to the public pages.
- *
- * @since 1.5.0
- *
- * @since 2.0.0 Update: Tooltips: fix disabling bug by loading jQuery UI library, thanks to @rajinderverma @ericcorbett2 @honlapdavid @mmallett bug reports, thanks to @vonpiernik code contribution.
- * @since 2.0.3 add versioning of public.css for cache busting
- * @since 2.0.4 add jQuery UI from WordPress
- * @since 2.1.4 automate passing version number for cache busting
- * @since 2.1.4 optionally enqueue an extra stylesheet
- */
- public function register_public() {
-
- /**
- * Enqueues external scripts.
- *
- * - Bugfix: Libraries: optimize processes by loading external and internal scripts only if needed, thanks to @docteurfitness issue report.
- *
- * @since 2.5.5
- * @reporter @docteurfitness
- * @link https://wordpress.org/support/topic/simply-speed-optimisation/
- *
- * The condition about tooltips was missing, only the not-alternative-tooltips part was present.
- */
- // Set conditions re-used for stylesheet enqueuing and in class/task.php.
- self::$a_bool_amp_enabled = Footnotes_Convert::to_bool( Footnotes_Settings::instance()->get( Footnotes_Settings::C_STR_FOOTNOTES_AMP_COMPATIBILITY_ENABLE ) );
- self::$a_bool_tooltips_enabled = Footnotes_Convert::to_bool( Footnotes_Settings::instance()->get( Footnotes_Settings::C_STR_FOOTNOTES_MOUSE_OVER_BOX_ENABLED ) );
- self::$a_bool_alternative_tooltips_enabled = Footnotes_Convert::to_bool( Footnotes_Settings::instance()->get( Footnotes_Settings::C_STR_FOOTNOTES_MOUSE_OVER_BOX_ALTERNATIVE ) );
- self::$a_str_script_mode = Footnotes_Settings::instance()->get( Footnotes_Settings::C_STR_FOOTNOTES_REFERENCE_CONTAINER_SCRIPT_MODE );
-
- /**
- * Enqueues the jQuery library registered by WordPress.
- *
- * - Bugfix: Reference container: optional alternative expanding and collapsing without jQuery for use with hard links, thanks to @hopper87it @pkverma99 issue reports.
- *
- * @since 2.5.6
- *
- * @reporter @hopper87it
- * @link https://wordpress.org/support/topic/footnotes-wp-rocket/
- *
- * jQuery is also used for animated scrolling, so it was loaded by default.
- * The function wp_enqueue_script() avoids loading the same library multiple times.
- * After adding the alternative reference container, jQuery has become optional,
- * but still enabled by default.
- */
- if ( ! self::$a_bool_amp_enabled ) {
-
- if ( 'jquery' === self::$a_str_script_mode || ( self::$a_bool_tooltips_enabled && ! self::$a_bool_alternative_tooltips_enabled ) ) {
-
- wp_enqueue_script( 'jquery' );
-
- }
-
- if ( self::$a_bool_tooltips_enabled && ! self::$a_bool_alternative_tooltips_enabled ) {
-
- /**
- * Enqueues the jQuery Tools library shipped with the plugin.
- *
- * Redacted jQuery.browser, completed minification;
- * see full header in js/jquery.tools.js.
- *
- * Add versioning.
- *
- * @since 2.1.2
- *
- * No '-js' in the handle, is appended automatically.
- *
- * Deferring to the footer breaks jQuery tooltip display.
- */
- wp_enqueue_script(
- 'mci-footnotes-jquery-tools',
- plugins_url( 'footnotes/js/jquery.tools.min.js' ),
- array(),
- '1.2.7.redacted.2',
- false
- );
-
- /**
- * Enqueues some jQuery UI libraries registered by WordPress.
- *
- * - Update: Tooltips: fix disabling bug by loading jQuery UI library, thanks to @rajinderverma @ericcorbett2 @honlapdavid @mmallett bug reports, thanks to @vonpiernik code contribution.
- *
- * @since 2.0.0
- *
- * @reporter @rajinderverma
- * @link https://wordpress.org/support/topic/tooltip-hover-not-showing/
- *
- * @reporter @ericcorbett2
- * @link https://wordpress.org/support/topic/tooltip-hover-not-showing/#post-13324142
- *
- * @reporter @honlapdavid
- * @link https://wordpress.org/support/topic/tooltip-hover-not-showing/#post-13355421
- *
- * @reporter @mmallett
- * @link https://wordpress.org/support/topic/tooltip-hover-not-showing/#post-13445437
- *
- * Fetch jQuery UI from cdnjs.cloudflare.com.
- * @since 2.0.0
- * @contributor @vonpiernik
- * @link https://wordpress.org/support/topic/tooltip-hover-not-showing/#post-13456762
- *
- * jQueryUI re-enables the tooltip infobox disabled when WPv5.5 was released. * @since 2.1.2
- *
- * - Update: Libraries: Load jQuery UI from WordPress, thanks to @check2020de issue report.
- *
- * @since 2.0.4
- * @reporter @check2020de
- * @link https://wordpress.org/support/topic/gdpr-issue-with-jquery/
- * @link https://wordpress.stackexchange.com/questions/273986/correct-way-to-enqueue-jquery-ui
- *
- * If alternative tooltips are enabled, these libraries are not needed.
- */
- wp_enqueue_script( 'jquery-ui-core' );
- wp_enqueue_script( 'jquery-ui-widget' );
- wp_enqueue_script( 'jquery-ui-position' );
- wp_enqueue_script( 'jquery-ui-tooltip' );
-
- }
- }
-
- /**
- * Enables enqueuing a new-scheme stylesheet.
- *
- * @since 2.5.5
- *
- * Enables enqueuing the formatted individual stylesheets if false.
- * WARNING: This facility is designed for development and must NOT be used in production.
- *
- * The Boolean may be set at the bottom of the plugin’s main PHP file.
- * @see footnotes.php
- */
- if ( PRODUCTION_ENV ) {
-
- /**
- * Enqueues a minified united external stylesheet in production.
- *
- * - Update: Stylesheets: increase speed and energy efficiency by tailoring stylesheets to the needs of the instance, thanks to @docteurfitness design contribution.
- * - Bugfix: Stylesheets: minify to shrink the carbon footprint, increase speed and implement best practice, thanks to @docteurfitness issue report.
- *
- * @since 2.5.5
- *
- * @contributor @docteurfitness
- * @link https://wordpress.org/support/topic/simply-speed-optimisation/
- *
- * @reporter @docteurfitness
- * @link https://wordpress.org/support/topic/simply-speed-optimisation/
- *
- * The dashboard stylesheet is minified as-is.
- * @see class/dashboard/layout.php
- *
- * @since 2.0.3 add versioning of public.css for cache busting.
- * Plugin version number is needed for busting browser caches after each plugin update.
- *
- * @since 2.1.4 automate passing version number for cache busting.
- * The constant C_STR_FOOTNOTES_VERSION is defined at start of footnotes.php.
- *
- * The media scope argument 'all' is the default.
- * No need to use '-css' in the handle, as this is appended automatically.
- */
- // Set tooltip mode for use in stylesheet name.
- if ( self::$a_bool_tooltips_enabled ) {
-
- if ( self::$a_bool_amp_enabled ) {
- $l_str_tooltip_mode_short = 'ampt';
- $l_str_tooltip_mode_long = 'amp-tooltips';
-
- } elseif ( self::$a_bool_alternative_tooltips_enabled ) {
- $l_str_tooltip_mode_short = 'altt';
- $l_str_tooltip_mode_long = 'alternative-tooltips';
-
- } else {
- $l_str_tooltip_mode_short = 'jqtt';
- $l_str_tooltip_mode_long = 'jquery-tooltips';
-
- }
- } else {
- $l_str_tooltip_mode_short = 'nott';
- $l_str_tooltip_mode_long = 'no-tooltips';
- }
-
- // Set basic responsive page layout mode for use in stylesheet name.
- $l_str_page_layout_option = Footnotes_Settings::instance()->get( Footnotes_Settings::C_STR_FOOTNOTES_PAGE_LAYOUT_SUPPORT );
- switch ( $l_str_page_layout_option ) {
- case 'reference-container':
- $l_str_layout_mode = '1';
- break;
- case 'entry-content':
- $l_str_layout_mode = '2';
- break;
- case 'main-content':
- $l_str_layout_mode = '3';
- break;
- case 'none':
- default:
- $l_str_layout_mode = '0';
- break;
- }
-
- // Enqueue the tailored united minified stylesheet.
- wp_enqueue_style(
- 'mci-footnotes-' . $l_str_tooltip_mode_long . '-pagelayout-' . $l_str_page_layout_option,
- plugins_url(
- Footnotes_Config::C_STR_PLUGIN_NAME . '/css/footnotes-' . $l_str_tooltip_mode_short . 'brpl' . $l_str_layout_mode . '.min.css'
- ),
- array(),
- C_STR_FOOTNOTES_VERSION,
- 'all'
- );
-
- } else {
-
- /**
- * Enqueues external stylesheets, ONLY in development now.
- *
- * @since 2.1.4 optionally enqueue an extra stylesheet.
- *
- * This optional layout fix is useful by lack of layout support.
- */
- wp_enqueue_style(
- 'mci-footnotes-common',
- plugins_url( Footnotes_Config::C_STR_PLUGIN_NAME . '/css/dev-common.css' ),
- array(),
- filemtime(
- plugin_dir_path(
- dirname( __FILE__, 1 )
- ) . 'css/dev-common.css'
- )
- );
- wp_enqueue_style(
- 'mci-footnotes-tooltips',
- plugins_url( Footnotes_Config::C_STR_PLUGIN_NAME . '/css/dev-tooltips.css' ),
- array(),
- filemtime(
- plugin_dir_path(
- dirname( __FILE__, 1 )
- ) . 'css/dev-tooltips.css'
- )
- );
-
- if ( self::$a_bool_amp_enabled ) {
- wp_enqueue_style(
- 'mci-footnotes-amp',
- plugins_url( Footnotes_Config::C_STR_PLUGIN_NAME . '/css/dev-amp-tooltips.css' ),
- array(),
- filemtime(
- plugin_dir_path(
- dirname( __FILE__, 1 )
- ) . 'css/dev-amp-tooltips.css'
- )
- );
- }
-
- if ( self::$a_bool_alternative_tooltips_enabled ) {
- wp_enqueue_style(
- 'mci-footnotes-alternative',
- plugins_url( Footnotes_Config::C_STR_PLUGIN_NAME . '/css/dev-tooltips-alternative.css' ),
- array(),
- filemtime(
- plugin_dir_path(
- dirname( __FILE__, 1 )
- ) . 'css/dev-tooltips-alternative.css'
- )
- );
- }
-
- $l_str_page_layout_option = Footnotes_Settings::instance()->get( Footnotes_Settings::C_STR_FOOTNOTES_PAGE_LAYOUT_SUPPORT );
- if ( 'none' !== $l_str_page_layout_option ) {
- wp_enqueue_style(
- 'mci-footnotes-layout-' . $l_str_page_layout_option,
- plugins_url(
- Footnotes_Config::C_STR_PLUGIN_NAME . '/css/dev-layout-' . $l_str_page_layout_option . '.css'
- ),
- array(),
- filemtime(
- plugin_dir_path(
- dirname( __FILE__, 1 )
- ) . 'css/dev-layout-' . $l_str_page_layout_option . '.css'
- ),
- 'all'
- );
- }
- }
- }
-}
diff --git a/src/class/config.php b/src/includes/config.php
similarity index 100%
rename from src/class/config.php
rename to src/includes/config.php
diff --git a/src/class/convert.php b/src/includes/convert.php
similarity index 100%
rename from src/class/convert.php
rename to src/includes/convert.php
diff --git a/src/class/dashboard/init.php b/src/includes/dashboard/init.php
similarity index 100%
rename from src/class/dashboard/init.php
rename to src/includes/dashboard/init.php
diff --git a/src/class/dashboard/layout.php b/src/includes/dashboard/layout.php
similarity index 100%
rename from src/class/dashboard/layout.php
rename to src/includes/dashboard/layout.php
diff --git a/src/class/dashboard/subpage-main.php b/src/includes/dashboard/subpage-main.php
similarity index 99%
rename from src/class/dashboard/subpage-main.php
rename to src/includes/dashboard/subpage-main.php
index 9d4f0b2..43b4275 100644
--- a/src/class/dashboard/subpage-main.php
+++ b/src/includes/dashboard/subpage-main.php
@@ -1143,7 +1143,7 @@ class Footnotes_Layout_Settings extends Footnotes_Layout_Engine {
* Edited:
* @since 2.1.6 drop localized notices for CSS classes as the number increased to 16
* list directly in the template, as CSS is in English anyway
- * @see templates/dashboard/customize-css.html
+ * @see admin/partials/customize-css.html
*
* @since 2.2.2 migrate Custom CSS to a dedicated tab
* @since 2.3.0 say 'copy-paste' instead of 'cut and paste' since cutting is not needed
@@ -1320,7 +1320,7 @@ class Footnotes_Layout_Settings extends Footnotes_Layout_Engine {
* @link https://blog.prototypr.io/why-testing-with-real-content-is-better-than-lorem-ipsum-c7c79586ee72
*/
public function Help() {
- global $g_obj_mci_footnotes;
+ global $footnotes;
// Load footnotes starting and end tag.
$l_arr_footnote_starting_tag = $this->load_setting( Footnotes_Settings::C_STR_FOOTNOTES_SHORT_CODE_START );
$l_arr_footnote_ending_tag = $this->load_setting( Footnotes_Settings::C_STR_FOOTNOTES_SHORT_CODE_END );
@@ -1356,7 +1356,7 @@ class Footnotes_Layout_Settings extends Footnotes_Layout_Engine {
'end' => $l_arr_footnote_ending_tag['value'],
'example-code' => $l_str_example,
'example-string' => '
' . __( 'will be displayed as:', 'footnotes' ),
- 'example' => $g_obj_mci_footnotes->a_obj_task->exec( $l_str_example, true ),
+ 'example' => $footnotes->a_obj_task->exec( $l_str_example, true ),
// Translators: %1$s, %2$s: anchor element with hyperlink to the Support Forum.
'information' => sprintf( __( 'For further information please check out our %1$sSupport Forum%2$s on WordPress.org.', 'footnotes' ), '' ),
)
@@ -1376,7 +1376,7 @@ class Footnotes_Layout_Settings extends Footnotes_Layout_Engine {
* When this callback function was renamed, this call went unnoticed.
* @see class/task.php
*/
- $g_obj_mci_footnotes->a_obj_task->footnotes_output_head();
+ $footnotes->a_obj_task->footnotes_output_head();
// Display template with replaced placeholders.
// phpcs:disable WordPress.Security.EscapeOutput.OutputNotEscaped
diff --git a/src/class/hooks.php b/src/includes/hooks.php
similarity index 100%
rename from src/class/hooks.php
rename to src/includes/hooks.php
diff --git a/src/class/language.php b/src/includes/language.php
similarity index 100%
rename from src/class/language.php
rename to src/includes/language.php
diff --git a/src/class/settings.php b/src/includes/settings.php
similarity index 100%
rename from src/class/settings.php
rename to src/includes/settings.php
diff --git a/src/class/task.php b/src/includes/task.php
similarity index 99%
rename from src/class/task.php
rename to src/includes/task.php
index 06f29e0..fbf4071 100644
--- a/src/class/task.php
+++ b/src/includes/task.php
@@ -863,7 +863,7 @@ class Footnotes_Task {
*
* Position and timing of jQuery tooltips are script defined.
*
- * @see templates/public/tooltip.html.
+ * @see public/partials/tooltip.html.
*/
$l_int_max_width = Footnotes_Settings::instance()->get( Footnotes_Settings::C_INT_FOOTNOTES_MOUSE_OVER_BOX_MAX_WIDTH );
if ( ! empty( $l_int_max_width ) && intval( $l_int_max_width ) > 0 ) {
@@ -1732,23 +1732,23 @@ class Footnotes_Task {
// Whether first clicking a referrer needs to expand the reference container.
if ( Footnotes_Convert::to_bool( Footnotes_Settings::instance()->get( Footnotes_Settings::C_STR_REFERENCE_CONTAINER_COLLAPSE ) ) ) {
- // Load 'templates/public/amp-footnote-expand.html'.
+ // Load 'public/partials/amp-footnote-expand.html'.
$l_obj_template = new Footnotes_Template( Footnotes_Template::C_STR_PUBLIC, 'amp-footnote-expand' );
} else {
- // Load 'templates/public/amp-footnote.html'.
+ // Load 'public/partials/amp-footnote.html'.
$l_obj_template = new Footnotes_Template( Footnotes_Template::C_STR_PUBLIC, 'amp-footnote' );
}
} elseif ( Footnotes::$a_bool_alternative_tooltips_enabled ) {
- // Load 'templates/public/footnote-alternative.html'.
+ // Load 'public/partials/footnote-alternative.html'.
$l_obj_template = new Footnotes_Template( Footnotes_Template::C_STR_PUBLIC, 'footnote-alternative' );
// Else jQuery tooltips are enabled.
} else {
- // Load 'templates/public/footnote.html'.
+ // Load 'public/partials/footnote.html'.
$l_obj_template = new Footnotes_Template( Footnotes_Template::C_STR_PUBLIC, 'footnote' );
// Load tooltip inline script.
@@ -2128,7 +2128,7 @@ class Footnotes_Task {
}
}
- // Fill in 'templates/public/footnote.html'.
+ // Fill in 'public/partials/footnote.html'.
$l_obj_template->replace(
array(
'link-span' => self::$a_str_link_span,
@@ -2160,7 +2160,7 @@ class Footnotes_Task {
$l_int_fade_out_delay = intval( Footnotes_Settings::instance()->get( Footnotes_Settings::C_INT_MOUSE_OVER_BOX_FADE_OUT_DELAY ) );
$l_int_fade_out_duration = intval( Footnotes_Settings::instance()->get( Footnotes_Settings::C_INT_MOUSE_OVER_BOX_FADE_OUT_DURATION ) );
- // Fill in 'templates/public/tooltip.html'.
+ // Fill in 'public/partials/tooltip.html'.
$l_obj_template_tooltip->replace(
array(
'post_id' => self::$a_int_post_id,
@@ -2807,22 +2807,22 @@ class Footnotes_Task {
// Whether the reference container is collapsed by default.
if ( Footnotes_Convert::to_bool( Footnotes_Settings::instance()->get( Footnotes_Settings::C_STR_REFERENCE_CONTAINER_COLLAPSE ) ) ) {
- // Load 'templates/public/amp-reference-container-collapsed.html'.
+ // Load 'public/partials/amp-reference-container-collapsed.html'.
$l_obj_template_container = new Footnotes_Template( Footnotes_Template::C_STR_PUBLIC, 'amp-reference-container-collapsed' );
} else {
- // Load 'templates/public/amp-reference-container.html'.
+ // Load 'public/partials/amp-reference-container.html'.
$l_obj_template_container = new Footnotes_Template( Footnotes_Template::C_STR_PUBLIC, 'amp-reference-container' );
}
} elseif ( 'js' === Footnotes::$a_str_script_mode ) {
- // Load 'templates/public/js-reference-container.html'.
+ // Load 'public/partials/js-reference-container.html'.
$l_obj_template_container = new Footnotes_Template( Footnotes_Template::C_STR_PUBLIC, 'js-reference-container' );
} else {
- // Load 'templates/public/reference-container.html'.
+ // Load 'public/partials/reference-container.html'.
$l_obj_template_container = new Footnotes_Template( Footnotes_Template::C_STR_PUBLIC, 'reference-container' );
}
diff --git a/src/class/widgets/base.php b/src/includes/widgets/base.php
similarity index 100%
rename from src/class/widgets/base.php
rename to src/includes/widgets/base.php
diff --git a/src/class/widgets/reference-container.php b/src/includes/widgets/reference-container.php
similarity index 95%
rename from src/class/widgets/reference-container.php
rename to src/includes/widgets/reference-container.php
index c2e801b..49c4ddb 100644
--- a/src/class/widgets/reference-container.php
+++ b/src/includes/widgets/reference-container.php
@@ -71,11 +71,11 @@ class Footnotes_Widget_Reference_Container extends Footnotes_Widget_Base {
* @param mixed $instance The instance of the widget.
*/
public function widget( $args, $instance ) {
- global $g_obj_mci_footnotes;
+ global $footnotes;
// Reference container positioning is set to "widget area".
if ( 'widget' === Footnotes_Settings::instance()->get( Footnotes_Settings::C_STR_REFERENCE_CONTAINER_POSITION ) ) {
// phpcs:disable WordPress.Security.EscapeOutput.OutputNotEscaped
- echo $g_obj_mci_footnotes->a_obj_task->reference_container();
+ echo $footnotes->a_obj_task->reference_container();
// phpcs:enable
}
}
diff --git a/src/class/wysiwyg.php b/src/includes/wysiwyg.php
similarity index 97%
rename from src/class/wysiwyg.php
rename to src/includes/wysiwyg.php
index 4c6dbd9..aade969 100644
--- a/src/class/wysiwyg.php
+++ b/src/includes/wysiwyg.php
@@ -78,7 +78,7 @@ class Footnotes_WYSIWYG {
* @return array
*/
public static function include_scripts( $p_arr_plugins ) {
- $p_arr_plugins[ Footnotes_Config::C_STR_PLUGIN_NAME ] = plugins_url( '/../js/wysiwyg-editor' . ( ( PRODUCTION_ENV ) ? '.min' : '' ) . '.js', __FILE__ );
+ $p_arr_plugins[ Footnotes_Config::C_STR_PLUGIN_NAME ] = plugins_url( '/../admin/js/wysiwyg-editor' . ( ( PRODUCTION_ENV ) ? '.min' : '' ) . '.js', __FILE__ );
return $p_arr_plugins;
}
diff --git a/src/class/template.php b/src/includes/template.php
similarity index 92%
rename from src/class/template.php
rename to src/includes/template.php
index dec1f82..4bc3e78 100644
--- a/src/class/template.php
+++ b/src/includes/template.php
@@ -19,20 +19,20 @@
class Footnotes_Template {
/**
* Directory name for dashboard templates.
*
* @since 1.5.0
* @var string
*/
- const C_STR_DASHBOARD = 'dashboard';
+ const C_STR_DASHBOARD = 'admin/partials';
/**
* Directory name for public templates.
*
* @since 1.5.0
* @var string
*/
- const C_STR_PUBLIC = 'public';
+ const C_STR_PUBLIC = 'public/partials';
/**
* Contains the content of the template after initialize.
@@ -198,8 +198,8 @@ class Footnotes_Template {
* return 'template_parts/footnotes/';
* } );
*/
- $template_directory = apply_filters( 'mci_footnotes_template_directory', 'footnotes/templates/' );
- $custom_directory = apply_filters( 'mci_footnotes_custom_template_directory', 'footnotes-custom/' );
+ $template_directory = apply_filters( 'footnotes_template_directory', 'footnotes/' );
+ $custom_directory = apply_filters( 'footnotes_custom_template_directory', 'footnotes-custom/' );
$template_name = $p_str_file_type . '/' . $p_str_file_name . '.' . $p_str_extension;
/**
@@ -223,10 +223,10 @@ class Footnotes_Template {
/**
* Fall back to the templates shipped with the plugin.
*/
- } elseif ( file_exists( $this->plugin_directory . 'templates/' . $template_name ) ) {
- $located = $this->plugin_directory . 'templates/' . $template_name;
+ } elseif ( file_exists( $this->plugin_directory . $template_name ) ) {
+ $located = $this->plugin_directory . $template_name;
}
-
+
return $located;
}
@@ -19,20 +19,20 @@
class Footnotes_Template {
/**
- * Directory name for dashboard templates.
+ * Directory name for dashboard partials.
*
* @since 1.5.0
@@ -19,20 +19,20 @@
/**
- * Directory name for public templates.
+ * Directory name for public partials.
*
* @since 1.5.0